==> hibernate-core-6.0.0.Final-sources.jar: hbm/org/hibernate/boot/jaxb/hbm/spi/JaxbHbmTuplizerType.java <==

package org.hibernate.boot.jaxb.hbm.spi;

import java.io.Serializable;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.hibernate.metamodel.RepresentationMode;


/**
 * 
 *                 TUPLIZER element; defines tuplizer to use for a component/entity for a given entity-mode
 *             
 * 
 * <p>Java class for tuplizer-type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="tuplizer-type"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="class" use="required" type="{http://www.hibernate.org/xsd/orm/hbm}ClassNameType" /&gt;
 *       &lt;attribute name="entity-mode" type="{http://www.hibernate.org/xsd/orm/hbm}EntityModeEnum" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "tuplizer-type", namespace = "http://www.hibernate.org/xsd/orm/hbm")
public class JaxbHbmTuplizerType
    implements Serializable
{

    @XmlAttribute(name = "class", required = true)
    protected String clazz;
    @XmlAttribute(name = "entity-mode")
    @XmlJavaTypeAdapter(Adapter4 .class)
    protected RepresentationMode entityMode;

    /**
     * Gets the value of the clazz property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getClazz() {
        return clazz;
    }

    /**
     * Sets the value of the clazz property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setClazz(String value) {
        this.clazz = value;
    }

    /**
     * Gets the value of the entityMode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public RepresentationMode getEntityMode() {
        return entityMode;
    }

    /**
     * Sets the value of the entityMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEntityMode(RepresentationMode value) {
        this.entityMode = value;
    }

}

==> hibernate-core-6.2.2.Final-sources.jar: hbm/org/hibernate/boot/jaxb/hbm/spi/JaxbHbmTuplizerType.java <==

package org.hibernate.boot.jaxb.hbm.spi;

import java.io.Serializable;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.hibernate.metamodel.RepresentationMode;


/**
 * 
 *                 TUPLIZER element; defines tuplizer to use for a component/entity for a given entity-mode
 *             
 * 
 * <p>Java class for tuplizer-type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="tuplizer-type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="class" use="required" type="{http://www.hibernate.org/xsd/orm/hbm}ClassNameType" />
 *       <attribute name="entity-mode" type="{http://www.hibernate.org/xsd/orm/hbm}EntityModeEnum" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "tuplizer-type", namespace = "http://www.hibernate.org/xsd/orm/hbm")
public class JaxbHbmTuplizerType
    implements Serializable
{

    @XmlAttribute(name = "class", required = true)
    protected String clazz;
    @XmlAttribute(name = "entity-mode")
    @XmlJavaTypeAdapter(Adapter4 .class)
    protected RepresentationMode entityMode;

    /**
     * Gets the value of the clazz property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getClazz() {
        return clazz;
    }

    /**
     * Sets the value of the clazz property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setClazz(String value) {
        this.clazz = value;
    }

    /**
     * Gets the value of the entityMode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public RepresentationMode getEntityMode() {
        return entityMode;
    }

    /**
     * Sets the value of the entityMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEntityMode(RepresentationMode value) {
        this.entityMode = value;
    }

}
